@@ -1,13 +1,13 @@
 /* bsign.cxx
-     $Id: bsign.cxx,v 1.25 2002/01/18 01:50:19 elf Exp $
+     $Id: bsign.cxx,v 1.26 2003/08/06 21:39:21 elf Exp $
 
-   written by Oscar Levi
+   written by Marc Singer
    1 December 1998 
 
    This file is part of the project BSIGN.  See the file README for
    more information.
 
-   Copyright (c) 1998 The Buici Company.
+   Copyright (c) 1998,2003 The Buici Company.
 
    This program is free software; you can redistribute it and/or modify 
    it under the terms of the GNU General Public License as published by
@@ -276,7 +276,8 @@ char* sign_file (char* pb, size_t cb, size_t ibSignature, size_t cbSignature,
   if (fCreateCert) {
     char* rgbCert = create_digital_signature (rgbSignature, cbHeader + 20);
     if (rgbCert) {
-      size_t cbCert = rgbCert[0]*256 + rgbCert[1] + 2;
+      size_t cbCert = ((unsigned char*)rgbCert)[0]*256
+	+ ((unsigned char*)rgbCert)[1] + 2;
       memcpy (pbHash + 20, rgbCert, cbCert);
       free (rgbCert);
     }
@@ -460,7 +461,8 @@ eExitStatus check_elf (char* pb, size_t cb, bool fExpectSignature)
     return result;
 
 				// Check digital signature if hash OK
-  size_t cbCert = (pb[ibHash + 20] << 8) | pb[ibHash + 21];
+  size_t cbCert = (((unsigned char*)pb)[ibHash + 20] << 8) 
+    | ((unsigned char*)pb)[ibHash + 21];
   if (cbCert == 0 || cbCert > cbSignature - (ibHash - ibSignature + 20))
     return badsignature;
   return verify_digital_signature (pb + ibSignature,
